@@ -528,7 +528,7 @@ gpm_applet_dialog_about_cb (GtkAction *action, gpointer data)
 static void
 gpm_applet_help_cb (GtkAction *action, gpointer data)
 {
-	gpm_help_display ("applets-inhibit");
+	gpm_help_display ("applets-general#applets-inhibit");
 }
 
 /**
