@@ -712,7 +712,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 					      &error
 					      );
 		if (error == NULL && res != NULL) {
-			g_variant_get(res,"(s)", &r);
+			g_variant_get(res,"(&s)", &r);
 			prefs->priv->can_shutdown = g_strcmp0(r,"yes")==0?TRUE:FALSE;
 			g_variant_unref (res);
 		} else if (error != NULL ) {
@@ -728,7 +728,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 					      &error
 					      );
 		if (error == NULL && res != NULL) {
-			g_variant_get(res,"(s)", &r);
+			g_variant_get(res,"(&s)", &r);
 			prefs->priv->can_suspend = g_strcmp0(r,"yes")==0?TRUE:FALSE;
 			g_variant_unref (res);
 		} else if (error != NULL ) {
@@ -744,7 +744,7 @@ gpm_prefs_init (GpmPrefs *prefs)
 					      &error
 					      );
 		if (error == NULL && res != NULL) {
-			g_variant_get(res,"(s)", &r);
+			g_variant_get(res,"(&s)", &r);
 			prefs->priv->can_hibernate = g_strcmp0(r,"yes")==0?TRUE:FALSE;
 			g_variant_unref (res);
 		} else if (error != NULL ) {
@@ -884,6 +884,7 @@ gpm_prefs_finalize (GObject *object)
 	g_object_unref (prefs->priv->settings);
 	g_object_unref (prefs->priv->client);
 	g_object_unref (prefs->priv->console);
+	g_object_unref (prefs->priv->builder);
 
 	G_OBJECT_CLASS (gpm_prefs_parent_class)->finalize (object);
 }
